@@ -15,6 +15,8 @@ from lino_xl.lib.ledger.choicelists import VoucherTypes
 from lino_xl.lib.ledger.ui import AccountBalances
 from lino_xl.lib.ledger.mixins import ItemsByVoucher
 from lino_xl.lib.ledger.roles import LedgerUser, LedgerStaff
+from lino.core import constants
+
 # from lino_xl.lib.ledger.fields import DebitOrCreditField
 # from lino_xl.lib.ledger.utils import DC.debit
 
@@ -346,7 +348,7 @@ class PrintableInvoicesByJournal(PrintableByJournal, Invoices):
 class ItemsByInvoice(ItemsByVoucher):
     model = 'ana.InvoiceItem'
     column_names = "account title ana_account vat_class total_base total_vat total_incl *"
-    display_mode_main = 'grid'
+    display_mode = ((None, constants.DISPLAY_MODE_TABLE), )
 
 
 
