@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2021 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import logging ; logger = logging.getLogger(__name__)
@@ -8,7 +8,13 @@ import logging ; logger = logging.getLogger(__name__)
 # import yaml
 # import base64
 
-from unipath import Path
+from pathlib import Path
+import shutil
+
+def needs_update(src, dst):
+    if not dst.exists():
+        return True
+    return src.stat().st_mtime > dst.stat().st_mtime
 
 from django.db import models
 from django.conf import settings
@@ -26,8 +32,8 @@ from lino.api import dd
 from .actions import BeIdReadCardAction, FindByBeIdAction
 from .choicelists import BeIdCardTypes
 
-MALE = Path(__file__).parent.child('luc.jpg')
-FEMALE = Path(__file__).parent.child('ly.jpg')
+MALE = Path(__file__).parent / 'luc.jpg'
+FEMALE = Path(__file__).parent / 'ly.jpg'
 
 
 class SSIN(dd.Model):
@@ -203,8 +209,8 @@ class BeIdCardHolder(SSIN):
         if card_number:
             parts = cls.get_image_parts(card_number)
             # return os.path.join(settings.MEDIA_ROOT, *parts)
-            return Path(settings.MEDIA_ROOT).child(*parts)
-        return Path(settings.STATIC_ROOT).child("contacts.Person.jpg")
+            return Path(settings.MEDIA_ROOT, *parts)
+        return settings.STATIC_ROOT / "contacts.Person.jpg"
 
     def get_image_url(self, ar):
         if self.card_number:
@@ -223,10 +229,10 @@ class BeIdCardHolder(SSIN):
         dst = self.get_image_path()
         # dst = settings.SITE.cache_dir.child(
         #     'media', 'beid', self.card_number + '.jpg')
-        if dst.needs_update([src]):
+        if needs_update(src, dst):
             logger.info("Create demo picture %s", dst)
             settings.SITE.makedirs_if_missing(dst.parent)
-            src.copy(dst)
+            shutil.copy(src, dst)
         else:
             logger.info("Demo picture %s is up-to-date", dst)
 
