@@ -5,6 +5,7 @@
 import datetime
 from io import StringIO
 from lxml import etree
+from html import escape
 
 from django.conf import settings
 from django.db import models
@@ -84,7 +85,7 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
 
     publisher_location = "bl"
     publisher_page_template = "blogs/entry_page.html"
-    publisher_item_template = "blogs/entry_item.html"
+    # publisher_item_template = "blogs/entry_item.html"
     preview_publication = PreviewPublication(label=_("Static View"))
 
     def __str__(self):
@@ -114,12 +115,14 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
     def preview(self, ar):
         if ar is None:
             return
-        return self.render_from(self.publisher_page_template, ar)
+        return ''.join(ar.row_as_page(self))
+        # return self.render_from(self.publisher_page_template, ar)
 
     def get_item_preview(self, ar):
         if ar is None:
             return
-        return self.render_from(self.publisher_item_template, ar)
+        # return self.render_from(self.publisher_item_template, ar)
+        return ar.row_as_paragraph(self)
 
     @dd.htmlbox()
     def item_preview(self, ar):
@@ -128,27 +131,57 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
     def as_story_item(self, ar):
         return self.get_item_preview(ar)
 
-    def get_preview_context(self, ar):
-        context = super().get_preview_context(ar)
+    def get_primary_image(self):
         FileUsage = rt.models.albums.FileUsage
         qs = FileUsage.objects.filter(
             **gfk2lookup(FileUsage.owner, self), primary_image=True)
-        if qs.count() == 1:
-            primary_image = qs[0].file
-            context.update(pi=primary_image)
+        return qs.first()
 
-        if ar.__class__ == BaseRequest:
-            return context
-
-        if ar.get_user() == self.user:
-            button = ('<span style="float: right;">' +
-                tostring(ar.row_action_button(self,
+    def as_page(self, ar):
+        title = self.title or self
+        img = self.get_primary_image()
+        pub_info = _("Published {date} by {author}").format(
+            date=self.pub_date.isoformat(),
+            author=tostring(ar.obj2html(self.user)))
+        if True:  # ar.get_user() == self.user:
+            btn = tostring(ar.row_action_button(self,
                     rt.models.blogs.MyEntries.detail_action, label='edit',
-                    icon_name=None, CLASS='pi pi-pencil')) +
-                '</span>')
-            context.update(editable=True, edit_button=button)
+                    icon_name=None, CLASS='pi pi-pencil'))
+            title += '<span style="float: right;">{}</span>'.format(btn)
 
-        return context
+        yield """<div style="max-width: 80ch; margin: auto">"""
+        yield "<h2>{}</h2>".format(title)
+        if img is not None:
+            yield """
+            <p><figure>
+            {img.thumbnail_large}
+            <figcaption style="text-align: center;">{img.description}</figcaption>
+            </figure></p>
+            """.format(img=img.file, obj=self)
+        yield """<span><em>{}</em></span>""".format(pub_info)
+        yield """<hr/>"""
+        # yield "<p>{}</p>".format(self.body_full_preview)
+        yield self.body_full_preview
+        yield "</div>"
+
+    def as_paragraph(self, ar):
+        img = self.get_primary_image()
+        pub_info = _("Published {date} by {author}").format(
+            date=self.pub_date.isoformat(),author=self.user)
+        url = escape(ar.renderer.obj2url(ar, self))
+        s = """<a href="{}"><strong>{}</strong> — """.format(url, ar.get_title())
+        s += """<span style="font-size:70%;"><em>{}</em></span></a>""".format(pub_info)
+        s += """<div style="display:flex;">"""
+        if img is not None:
+            s += """<div><a href="{url}">{img.thumbnail}</a></div>""".format(
+                img=img.file, url=url)
+        else:
+            s += """<div>no image</div>"""
+        s += """<div style="margin-left:20px;"><p style="text-align:justify;">"""
+        s += self.body_short_preview
+        s += """</p></div>"""
+        s += """</div>"""
+        return s
 
     @classmethod
     def get_dashboard_items(cls, user):
@@ -228,8 +261,7 @@ class Entries(dd.Table):
 
     hide_top_toolbar = False
 
-    display_mode_main = 'list'
-    disabled_display_mode = None # Something to play with (TODO)
+    display_mode = ((None, constants.DISPLAY_MODE_LIST), )
 
     insert_layout = """
     title
@@ -237,7 +269,7 @@ class Entries(dd.Table):
     """
 
     detail_layout = EntryDetail()
-    item_layout = ItemLayout()
+    list_layout = ItemLayout()
 
     @classmethod
     def collect_extra_actions(cls):
@@ -255,9 +287,9 @@ class PublicEntries(Entries):
     comments.CommentsByRFC
     """
 
-    display_mode_main = constants.DISPLAY_MODE_STORY
+    display_mode = ((None, constants.DISPLAY_MODE_STORY), )
 
-    item_layout = "item_preview"
+    list_layout = "item_preview"
 
     @classmethod
     def collect_extra_actions(cls):
@@ -295,7 +327,7 @@ class EntriesByController(Entries):
     master_key = 'owner'
     column_names = "pub_date title user *"
     order_by = ["-pub_date"]
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
 
     @classmethod
     def get_table_summary(self, mi, ar):
@@ -336,6 +368,7 @@ class LatestEntries(PublicEntries):
     column_names = "pub_date title user *"
     order_by = ["-pub_date"]
     filter = models.Q(pub_date__isnull=False)
+    display_mode = ((None, constants.DISPLAY_MODE_LIST), )
 
     @classmethod
     def get_table_summary(cls, obj, ar, max_num=10, **context):
@@ -366,7 +399,7 @@ class LatestEntries(PublicEntries):
 
         return E.div(*elems)
 
-PublisherViews.add_item_lazy(LatestEntries)
+PublisherViews.add_item_lazy("latest", LatestEntries)
 
 
 # class Taggings(dd.Table):
