@@ -1244,8 +1244,9 @@ class Guest(Printable):   # TODO: rename the model to "Presence"
         # m = dd.plugins.cal.partner_model
         # return m.objects.order_by(*m.get_default_table().order_by)
 
-    def create_partner_choice(self, text, ar=None):
-        return dd.plugins.cal.partner_model.create_from_choice(text)
+    def create_partner_choice(self, *args, **kwargs):
+        # This is a create_FOO_choice method
+        return dd.plugins.cal.partner_model.create_from_choice(*args, **kwargs)
 
     def delete(self, **kw):
         super(Guest, self).delete(**kw)
