@@ -29,6 +29,7 @@ from .choicelists import EventEvents
 from .mixins import daterange_text
 from .utils import when_text
 from .roles import CalendarReader, GuestOperator, CalendarGuest
+from lino.core import constants
 
 class RemoteCalendars(dd.Table):
     model = 'cal.RemoteCalendar'
@@ -235,7 +236,7 @@ class TasksByController(Tasks):
     column_names = 'priority start_date summary workflow_buttons id'
     # hidden_columns = set('owner_id owner_type'.split())
     auto_fit_column_widths = True
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
 
 
@@ -272,7 +273,7 @@ class TasksByProject(Tasks):
     required_roles = dd.login_required((OfficeUser, OfficeOperator))
     master_key = 'project'
     column_names = 'priority start_date user summary owner workflow_buttons *'
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
 
 class GuestRoles(dd.Table):
@@ -439,7 +440,7 @@ class GuestsByPartner(Guests):
     # required_roles = dd.login_required(OfficeUser)
     column_names = 'event__when_text event_summary event__user role workflow_buttons *'
     auto_fit_column_widths = True
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     order_by = ['-event__start_date', '-event__start_time']
 
     @classmethod
@@ -992,7 +993,7 @@ class EntriesByController(Events):
     column_names = 'when_text summary workflow_buttons auto_type user event_type *'
     # column_names = 'when_text:20 when_html summary workflow_buttons *'
     auto_fit_column_widths = True
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     order_by = ["-start_date", "-start_time", "auto_type", "id"]
     # order_by = ['seqno']
 
@@ -1034,7 +1035,7 @@ class EntriesByGuest(Events):
     summary
     event_type
     """
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     order_by = ['-start_date', '-start_time']
 
     @classmethod
