@@ -29,6 +29,7 @@ from lino_xl.lib.cal.choicelists import DurationUnits, YearMonths
 from lino_xl.lib.cal.utils import when_text
 
 from .mixins import Plannable, Planner
+from lino.core import constants
 
 CALENDAR = PythonCalendar()
 
@@ -152,7 +153,7 @@ class Day(TableRow):
 
     @classmethod
     def setup_parameters(cls, params):
-        super(Day, cls).setup_parameters(params)
+        super().setup_parameters(params)
         Event = rt.models.cal.Event
         Event.setup_parameters(params)
 
@@ -163,6 +164,8 @@ class Day(TableRow):
         # for k in event_fields:
         for k in ('user', 'event_type', 'room', 'project'):
             params[k] = dbfield2params_field(Event.get_data_elem(k))
+            # for k, pf in dbfield2params_field(Event.get_data_elem(name)):
+            #     params[k] = pf
             # params[k] = dbfield2params_field(Event._meta.get_field(k))
 
 
@@ -229,7 +232,7 @@ class DayNavigator(DaysTable):
         user=dd.ForeignKey('users.User', null=True, blank=True))
     column_names = "detail_link *"
     params_panel_hidden = False
-    display_mode_main = "html"
+    display_mode = ((None, constants.DISPLAY_MODE_HTML), )
     # hide_top_toolbar = True
     planner = None  # must be set for concrete subclasses
 
@@ -783,7 +786,7 @@ class MonthlySlaveBase(DaySlave, VentilatedColumns):
 
 
 class DailyPlanner(ParameterClone, DailySlaveBase, DailyPlannerRows):
-    # display_mode_main = "html"
+    # display_mode = ((None, constants.DISPLAY_MODE_HTML), )
     navigation_mode = 'day'
 
 class DailySlave(DailyPlanner):
@@ -794,7 +797,7 @@ class DailySlave(DailyPlanner):
 class WeeklySlave(ParameterClone, WeeklySlaveBase, DailyPlannerRows):
     # model = 'calview.DailyPlannerRow'
     # required_roles = dd.login_required(OfficeStaff)
-    # display_mode_main = "html"
+    # display_mode = ((None, constants.DISPLAY_MODE_HTML), )
 
     title = _("Planner")
 
