@@ -1,9 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2017 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-"""Model mixins for `lino_xl.lib.contacts`.
-"""
-from builtins import object
 
 from django.db import models
 from django.conf import settings
@@ -13,17 +10,15 @@ from lino.api import dd, rt
 from etgen.html import lines2p, tostring
 
 
-class ContactRelated(dd.Model):
+class AbstractContactRelated(dd.Model):
 
-    class Meta(object):
+    # This is actually the ContactRelated mixin, except that it does not define
+    # the company field. For example welfare.modlib.isip uses this to define
+    # that field itself using a subclass of Company.
+
+    class Meta:
         abstract = True
 
-    company = dd.ForeignKey(
-        "contacts.Company",
-        related_name="%(app_label)s_%(class)s_set_by_company",
-        verbose_name=_("Organization"),
-        blank=True, null=True)
-
     contact_person = dd.ForeignKey(
         "contacts.Person",
         related_name="%(app_label)s_%(class)s_set_by_contact_person",
@@ -38,14 +33,20 @@ class ContactRelated(dd.Model):
 
     @dd.chooser()
     def contact_person_choices(cls, company):
-        """
-        chooser method for the `contact_person` field.
-        """
+        # needed to activate create_contact_person_choice
+        # chooser method for the `contact_person` field.
         if company is not None:
             return cls.contact_person_choices_queryset(company)
         return rt.models.contacts.Person.objects.order_by(
             'last_name', 'first_name')
 
+    def create_contact_person_choice(self, *args, **kwargs):
+        person = rt.models.contacts.Person.create_from_choice(*args, **kwargs)
+        role = rt.models.contacts.Role(company=self.company, person=person)
+        role.full_clean()
+        role.save()
+        return person
+
     def get_contact(self):
         if self.contact_person is not None:
             if self.company is not None:
@@ -76,7 +77,7 @@ class ContactRelated(dd.Model):
         """Implements :meth:`lino.core.model.Model.get_excerpt_options`.
 
         """
-        kw = super(ContactRelated, self).get_excerpt_options(ar, **kw)
+        kw = super().get_excerpt_options(ar, **kw)
         kw.update(company=self.company)
         kw.update(contact_person=self.contact_person)
         kw.update(contact_role=self.contact_role)
@@ -124,7 +125,7 @@ class ContactRelated(dd.Model):
         Return a queryset of candidate Person objects allowed
         in `contact_person` for a given `company`.
         """
-        return settings.SITE.models.contacts.Person.objects.filter(
+        return rt.models.contacts.Person.objects.filter(
             rolesbyperson__company=company).distinct()
 
     def full_clean(self, *args, **kw):
@@ -141,7 +142,7 @@ class ContactRelated(dd.Model):
             if contact is not None:
                 self.contact_role = contact.type
                 #~ print '20120929b', contact.type
-        super(ContactRelated, self).full_clean(*args, **kw)
+        super().full_clean(*args, **kw)
 
     def get_invoiceable_partner(self):
         return self.partner
@@ -167,9 +168,23 @@ class ContactRelated(dd.Model):
         raise Warning("{} is neither person nor company".format(partner))
 
 
+
+class ContactRelated(AbstractContactRelated):
+
+    class Meta:
+        abstract = True
+
+    company = dd.ForeignKey(
+        "contacts.Company",
+        related_name="%(app_label)s_%(class)s_set_by_company",
+        verbose_name=_("Organization"),
+        blank=True, null=True)
+
+
+
 class PartnerDocument(dd.Model):
 
-    class Meta(object):
+    class Meta:
         abstract = True
 
     company = dd.ForeignKey("contacts.Company", blank=True, null=True)
@@ -219,49 +234,49 @@ class PartnerDocument(dd.Model):
                 other.project = self.company
         other.person = self.person
         other.company = self.company
-        super(PartnerDocument, self).update_owned_instance(other)
+        super().update_owned_instance(other)
 
 
-class OldCompanyContact(dd.Model):
-
-    """
-    Abstract class which adds two fields `company` and `contact`.
-    """
-    class Meta(object):
-        abstract = True
-
-    company = dd.ForeignKey(
-        "contacts.Company",
-        related_name="%(app_label)s_%(class)s_set_by_company",
-        verbose_name=_("Company"),
-        blank=True, null=True)
-
-    contact = dd.ForeignKey(
-        "contacts.Role",
-        related_name="%(app_label)s_%(class)s_set_by_contact",
-        blank=True, null=True,
-        verbose_name=_("represented by"))
-
-    @dd.chooser()
-    def contact_choices(cls, company):
-        if company is not None:
-            return cls.contact_choices_queryset(company)
-        return []
-
-    @classmethod
-    def contact_choices_queryset(cls, company):
-        return rt.models.contacts.Role.objects.filter(company=company)
-
-    def full_clean(self, *args, **kw):
-        if self.company:
-            if self.contact is None \
-                or self.contact.company is None \
-                    or self.contact.company.pk != self.company.pk:
-                qs = self.contact_choices_queryset(self.company)
-                #~ qs = self.company.rolesbyparent.all()
-                if qs.count() == 1:
-                    self.contact = qs[0]
-                else:
-                    #~ print "20120227 clear contact!"
-                    self.contact = None
-        super(OldCompanyContact, self).full_clean(*args, **kw)
+# class OldCompanyContact(dd.Model):
+#
+#     """
+#     Abstract class which adds two fields `company` and `contact`.
+#     """
+#     class Meta(object):
+#         abstract = True
+#
+#     company = dd.ForeignKey(
+#         "contacts.Company",
+#         related_name="%(app_label)s_%(class)s_set_by_company",
+#         verbose_name=_("Company"),
+#         blank=True, null=True)
+#
+#     contact = dd.ForeignKey(
+#         "contacts.Role",
+#         related_name="%(app_label)s_%(class)s_set_by_contact",
+#         blank=True, null=True,
+#         verbose_name=_("represented by"))
+#
+#     @dd.chooser()
+#     def contact_choices(cls, company):
+#         if company is not None:
+#             return cls.contact_choices_queryset(company)
+#         return []
+#
+#     @classmethod
+#     def contact_choices_queryset(cls, company):
+#         return rt.models.contacts.Role.objects.filter(company=company)
+#
+#     def full_clean(self, *args, **kw):
+#         if self.company:
+#             if self.contact is None \
+#                 or self.contact.company is None \
+#                     or self.contact.company.pk != self.company.pk:
+#                 qs = self.contact_choices_queryset(self.company)
+#                 #~ qs = self.company.rolesbyparent.all()
+#                 if qs.count() == 1:
+#                     self.contact = qs[0]
+#                 else:
+#                     #~ print "20120227 clear contact!"
+#                     self.contact = None
+#         super().full_clean(*args, **kw)
