@@ -11,6 +11,8 @@ from django.core.exceptions import ValidationError
 from django.db import models
 from django.db.models import Q
 
+from etgen.html import tostring
+
 from lino import mixins
 from lino.api import dd, rt, _
 from lino.mixins.duplicable import Duplicable
@@ -323,6 +325,17 @@ class Partner(Duplicable, ContactDetailsOwner, mixins.Polymorphic,
         elems += ContactDetailsOwner.get_overview_elems(self, ar)
         return elems
 
+    def as_paragraph(self, ar):
+        elems = []
+        elems += self.get_name_elems(ar)
+        elems.append(E.br())
+        elems += join_elems(list(self.address_location_lines()), sep=E.br)
+        # elems += AddressOwner.get_overview_elems(self, ar)
+        # elems += ContactDetailsOwner.get_overview_elems(self, ar)
+        return "".join([tostring(e) for e in elems])
+        # return tostring(E.div(*elems))
+
+
     def get_name_elems(self, ar):
         elems = []
         if self.prefix:
@@ -529,7 +542,7 @@ class Person(Human, Born, Partner):
             family=self.last_name, given=self.first_name )
 
     @classmethod
-    def choice_text_to_dict(cls, text):
+    def choice_text_to_dict(cls, text, ar):
         return parse_name(text)
         # try:
         #     kw = parse_name(text)
@@ -588,8 +601,10 @@ class CompanyType(mixins.BabelNamed):
     class Meta(object):
         app_label = 'contacts'  # avoid RemovedInDjango19Warning
         abstract = dd.is_abstract_model(__name__, 'CompanyType')
-        verbose_name = _("Organization type")
-        verbose_name_plural = _("Organization types")
+        # verbose_name = _("Organization type")
+        # verbose_name_plural = _("Organization types")
+        verbose_name = _("Legal form")
+        verbose_name_plural = _("Legal forms")
 
     abbr = dd.BabelCharField(_("Abbreviation"), max_length=30, blank=True)
 
@@ -729,8 +744,8 @@ class Role(dd.Model, Addressable):
         # needed to activate create_person_choice
         return rt.models.contacts.Person.objects.all()
 
-    def create_person_choice(self, text, ar=None):
-        return rt.models.contacts.Person.create_from_choice(text)
+    def create_person_choice(self, *args, **kwargs):
+        return rt.models.contacts.Person.create_from_choice(*args, **kwargs)
 
 
 
