@@ -15,6 +15,7 @@ from django.utils.text import format_lazy
 from lino.api import dd, rt, _
 from lino import mixins
 
+from lino.core import constants
 from lino.core.roles import Explorer
 from lino.utils import join_elems
 from etgen.html import E
@@ -194,7 +195,7 @@ class Activities(dd.Table):
 
     @classmethod
     def get_simple_parameters(cls):
-        s = list(super(Activities, cls).get_simple_parameters())
+        s = list(super().get_simple_parameters())
         s.append('line')
         s.append('teacher')
         # s.append('state')
@@ -257,6 +258,12 @@ class ActivitiesByLayout(Activities):
         return ActivityLayouts.get_by_name(self.activity_layout).text
         # return super(Activities, self).get_actor_label()
 
+    @classmethod
+    def param_defaults(cls, ar, **kw):
+        kw = super().param_defaults(ar, **kw)
+        kw.update(show_exposed=dd.YesNo.yes)
+        return kw
+
     @dd.chooser()
     def line_choices(cls):
         # dd.logger.info("20181104 line_choices %s", cls)
@@ -267,7 +274,7 @@ class ActivitiesByLayout(Activities):
     @classmethod
     def create_instance(cls, ar, **kw):
         # dd.logger.info("20160714 %s", kw)
-        obj = super(ActivitiesByLayout, cls).create_instance(ar, **kw)
+        obj = super().create_instance(ar, **kw)
         al = ActivityLayouts.get_by_name(cls.activity_layout)
         obj.course_area = al
         qs = rt.models.courses.Line.objects.filter(course_area=al)
@@ -632,7 +639,7 @@ class EnrolmentsByCourse(Enrolments):
                    'remark workflow_buttons *'
     auto_fit_column_widths = True
     # cell_edit = False
-    display_mode_main = 'html'
+    display_mode = ((None, constants.DISPLAY_MODE_HTML), )
 
     insert_layout = """
     pupil
