@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2021 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino_xl.lib.ledger.utils import ZERO, ONE
@@ -47,7 +47,7 @@ except AttributeError:
     # not installed.
     teacher_label = _("Instructor")
     teacher_model = 'foo.Bar'
-    pupil_model = 'foo.Bar'
+    pupil_model = None
     pupil_name_fields = 'foo bar'
 
 FILL_EVENT_GUESTS = False
@@ -574,8 +574,8 @@ class Enrolment(UserAuthored, Certifiable, DateRange):
 
     @dd.chooser()
     def pupil_choices(cls, course):
-        Pupil = dd.resolve_model(pupil_model)
-        return Pupil.objects.all()
+        # Pupil = dd.resolve_model(pupil_model)
+        return pupil_model.objects.all()
 
     def create_pupil_choice(self, text, ar=None):
         """
@@ -583,9 +583,9 @@ class Enrolment(UserAuthored, Certifiable, DateRange):
         Try to auto-create it.
         """
 
-    def create_pupil_choice(self, text, ar=None):
-        Pupil = dd.resolve_model(pupil_model)
-        return Pupil.create_from_choice(text)
+    def create_pupil_choice(self, *args, **kwargs):
+        # Pupil = dd.resolve_model(pupil_model)
+        return pupil_model.create_from_choice(*args, **kwargs)
 
         # kw = parse_name(text)
         # if len(kw) != 2:
