@@ -19,7 +19,7 @@ from .mixins import (SectorFunction, PersonHistoryEntry,
                      EducationEntryStates)
 
 from .roles import CareerUser, CareerStaff
-
+from lino.core import constants
 config = dd.plugins.cv
 
 
@@ -89,7 +89,7 @@ class LanguageKnowledgesByPerson(LanguageKnowledges):
     column_names = "language native spoken written cef_level has_certificate entry_date *"
     required_roles = dd.login_required(CareerUser)
     auto_fit_column_widths = True
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
     window_size  = (70, 15)
     detail_layout = dd.DetailLayout("""
     language
