@@ -1,4 +1,4 @@
-# Copyright 2008-2020 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
@@ -21,6 +21,7 @@ from .mixins import (FinancialVoucher, FinancialVoucherItem,
                      DatedFinancialVoucher, DatedFinancialVoucherItem)
 
 from .actions import WritePaymentsInitiation
+from lino.core import constants
 
 
 ledger = dd.resolve_app('ledger')
@@ -395,7 +396,7 @@ from lino_xl.lib.ledger.mixins import ItemsByVoucher
 # class ItemsByVoucher(ItemsByVoucher):
 #     suggest = ShowSuggestions()
 #     suggestions_table = None  # 'finan.SuggestionsByJournalEntry'
-    # display_mode_main = 'html'
+    # display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     # preview_limit = 0
     # label = _("Content")
 
