@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2017-2021 Rumma & Ko Ltd
+# Copyright 2017-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
@@ -14,7 +14,7 @@ from lino.modlib.comments.mixins import Commentable, PrivateCommentsReader
 from lino.modlib.users.mixins import UserAuthored, My
 from lino.modlib.notify.mixins import ChangeNotifier
 from lino.core.roles import SiteAdmin, SiteUser  # , UserRole
-
+from lino.core import constants
 
 class Group(mixins.BabelNamed, mixins.Referrable, ChangeNotifier,
             Commentable):
@@ -153,7 +153,7 @@ class MembershipsByGroup(Memberships):
     master_key = 'group'
     column_names = "user remark workflow_buttons *"
     stay_in_grid = True
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
     # summary_sep = comma
 
@@ -185,7 +185,7 @@ class MembershipsByUser(Memberships):
     master_key = 'user'
     column_names = "group remark *"
     order_by = ['group__ref']
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     required_roles = dd.login_required(SiteUser)
 
 
