@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import logging ; logger = logging.getLogger(__name__)
@@ -9,6 +9,7 @@ from django.conf import settings
 
 from lino.api import dd, rt, _, gettext
 from lino import mixins
+from lino.core import constants
 
 from lino.utils import join_words, join_elems
 from etgen.html import E
@@ -398,7 +399,7 @@ class SiblingsByPerson(Members):
     # column_names = 'person role start_date end_date *'
     order_by = ['birth_date']
     auto_fit_column_widths = True
-    # display_mode_main = 'summary'
+    # display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     window_size = (100, 20)
 
     @classmethod
@@ -535,7 +536,7 @@ class MembersByPerson(Members):
     """
     # auto_fit_column_widths = True
     # hide_columns = 'id'
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     stay_in_grid = True
 
     @classmethod
