@@ -1,11 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2021 Rumma & Ko Ltd
+# Copyright 2014-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import logging
 logger = logging.getLogger(__name__)
 
 from django.core.exceptions import ValidationError
+from lino.core import constants
 from django.db.models import Q
 from lino_xl.lib.contacts.roles import ContactsUser, ContactsStaff
 
@@ -105,7 +106,7 @@ class LinksByHuman(Links):
     required_roles = dd.login_required(ContactsUser)
     master = config.person_model
     column_names = 'parent type_as_parent:10 child'
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
     addable_link_types = (
         LinkTypes.parent, LinkTypes.adoptive_parent,
