@@ -30,6 +30,7 @@ class Plugin(Plugin):
     """
 
     # default_voucher_view = 'lino_xl.lib.sales.ui.InvoicesByJournal'
+    voucher_type = 'sales.InvoicesByJournal'
     voucher_model = 'sales.VatProductInvoice'
     item_model = 'sales.InvoiceItem'
     """
@@ -50,36 +51,46 @@ class Plugin(Plugin):
     instead of one.
     """
 
-    delivery_notes_demo = False
-    """
-    Whether the :fixture:`demo` fixtures should generate delivery notes.
-    """
+    # delivery_notes_demo = False
+    # """
+    # Whether the :fixture:`demo` fixtures should generate delivery notes.
+    # """
+
+    def on_site_startup(self, site):
+        super().on_site_startup(site)
+        # self.default_voucher_view = import_string(self.default_voucher_view)
 
-    # def on_site_startup(self, site):
-    #     super().on_site_startup(site)
-    #     self.default_voucher_view = import_string(self.default_voucher_view)
 
     def before_analyze(self):
         # print("20210722 before_analyze()")
         from lino.core.utils import resolve_model
+        self.voucher_model = resolve_model(self.voucher_model)
         self.item_model = resolve_model(self.item_model)
         # ivm = self.item_model._meta.get_field('voucher').remote_field.model
         # if self.voucher_model != ivm:
         #     raise Exception("voucher_model is {} but should be {}".format(
         #         self.voucher_model, ivm))
-        self.voucher_model = resolve_model(self.voucher_model)
         # assert issubclass(self.default_voucher_view, dbtables.Table)
+
         if self.order_model is not None:
             self.order_model = resolve_model(self.order_model)
 
+    # def on_ui_init(self, kernel):
+    #     if type(self.voucher_type) == str:
+    #         VoucherTypes = self.site.models.ledger.VoucherTypes
+    #         self.voucher_type = VoucherTypes.get_by_value(self.voucher_type)
+    #     assert self.voucher_type.model is self.voucher_model
+    #     assert self.voucher_type.get_items_model() is self.item_model
+
     def get_voucher_type(self):
         # from lino.core.utils import resolve_model
         # model = resolve_model(self.voucher_model)
         # return self.site.modules.ledger.VoucherTypes.get_for_model(model)
         # return self.site.models.ledger.VoucherTypes.get_for_model(
         #     self.voucher_model)
+        # return self.voucher_type
         for i in self.site.models.ledger.VoucherTypes.get_list_items():
-            if issubclass(i.model, self.voucher_model):
+            if i.model is self.voucher_model:
                 return i
         raise Exception("20220512 No voucher type for %s" % self.voucher_model)
         # return self.site.models.ledger.VoucherTypes.get_for_model(
