@@ -23,8 +23,12 @@ def objects():
     if users.count() == 0:
         return
     ses = rt.login(users.first().username)
+    # print("20220707", list(Area.objects.all()))
 
     for area in Area.objects.all():
+        # print("20220707", area, area.journal)
+        if area.journal is None:
+            continue
         min_date = None
         today = datetime.date(dd.plugins.ledger.start_year, 1, 1)
         while today < dd.demo_date(-60):
