@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino.api import dd, rt, _
@@ -14,13 +14,13 @@ bevat = dd.resolve_app('bevat')
 eevat = dd.resolve_app('eevat')
 bevats = dd.resolve_app('bevats')
 #~ partners = dd.resolve_app('partners')
+has_payment_methods = dd.get_plugin_setting('ledger', 'has_payment_methods', False)
 
 
 def objects():
 
     JournalGroups = rt.models.ledger.JournalGroups
     Company = rt.models.contacts.Company
-    PaymentMethod = rt.models.ledger.PaymentMethod
 
     # JOURNALS
 
@@ -44,22 +44,49 @@ def objects():
     SLS_JOURNAL = MODEL.create_journal(**kw)
     yield SLS_JOURNAL
 
-    if dd.is_installed('invoicing') and dd.plugins.invoicing.delivery_notes_demo:
-        kw.update(ref="SDN", dc=DC.credit)
-        kw.update(dd.str2kw('printed_name', _("Delivery note")))
-        kw.update(dd.str2kw('name', _("Delivery notes")))
-        kw.update(make_ledger_movements=False)
+    # if dd.is_installed('invoicing') and dd.plugins.invoicing.delivery_notes_demo:
+    # stories_journal = dd.plugins.ledger.sales_stories_journal
+    sales_method = dd.plugins.ledger.sales_method
+    if sales_method and sales_method != 'direct':
         misc_partner = rt.models.contacts.Company(
             name="Miscellaneous",
             country=dd.plugins.countries.get_my_country())
         yield misc_partner
         kw.update(partner=misc_partner)
-        SDN_JOURNAL = sales.SalesNotesByJournal.create_journal(**kw)
+        if sales_method == "delivery":
+            kw.update(ref="SDN", dc=DC.credit)
+            kw.update(dd.str2kw('printed_name', _("Delivery note")))
+            kw.update(dd.str2kw('name', _("Delivery notes")))
+            kw.update(make_ledger_movements=False)
+        elif sales_method == "pos":
+            kw.update(ref="SSN", dc=DC.credit)
+            kw.update(dd.str2kw('printed_name', _("Sales note")))
+            kw.update(dd.str2kw('name', _("Sales notes")))
+            kw.update(make_ledger_movements=True)
+        else:
+            raise Exception("Unsupported sales method {}".format(sales_method))
+        SDN_JOURNAL = sales.CashInvoicesByJournal.create_journal(**kw)
         yield SDN_JOURNAL
-        yield PaymentMethod(designation=_("Cash payment"), journal=SDN_JOURNAL)
         yield rt.models.invoicing.FollowUpRule(
             source_journal=SDN_JOURNAL,
             target_journal=SLS_JOURNAL)
+        # yield PaymentMethod(designation=_("Cash payment"), journal=SDN_JOURNAL)
+
+    if has_payment_methods:
+
+        PaymentMethod = rt.models.ledger.PaymentMethod
+
+        def payment_method(designation, payment_account, **kwargs):
+            if payment_account:
+                kwargs.update(payment_account=CommonAccounts.get_by_name(
+                    payment_account).get_object())
+            # kwargs.update(journal=SLS_JOURNAL)
+            return PaymentMethod(**dd.str2kw('designation', designation, **kwargs))
+
+        yield payment_method(_("Cash payment"), "cash", is_cash=True)
+        yield payment_method(_("PayPal"), "online_payments")
+        yield payment_method(_("bKash"), "online_payments")
+        # yield payment_method(_("Cash on delivery"), "cash")
 
     if dd.plugins.vat.declaration_plugin is None:
         dd.logger.warning("No journal SLC, BNK, PMO etc because declaration_plugin is None")
@@ -182,14 +209,3 @@ def objects():
     # if pending_po:
     #     for jnl in ledger.Journal.objects.filter(voucher_type__in=VoucherTypes.finan.BankStatement):
     #         yield MatchRule(journal=jnl, account=pending_po)
-
-
-    PaymentMethod = rt.models.ledger.PaymentMethod
-
-    def payment_method(designation, **kwargs):
-        kwargs.update(journal=SLS_JOURNAL)
-        return PaymentMethod(**dd.str2kw('designation', designation, **kwargs))
-
-    yield payment_method(_("PayPal"))
-    yield payment_method(_("bKash"))
-    yield payment_method(_("Cash on delivery"))
