@@ -14,6 +14,7 @@ from lino.api import dd, rt, _
 
 from .choicelists import VoucherTypes, TradeTypes, VoucherStates
 from .roles import LedgerUser
+from lino.core import constants
 
 project_model = dd.get_plugin_setting('ledger', 'project_model', None)
 has_payment_methods = dd.get_plugin_setting('ledger', 'has_payment_methods', False)
@@ -397,7 +398,7 @@ class ItemsByVoucher(dd.Table):
     master_key = 'voucher'
     order_by = ["seqno"]
     auto_fit_column_widths = True
-    # display_mode_main = 'html'
+    # display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     preview_limit = 0
 
 class VouchersByPartnerBase(dd.VirtualTable):
@@ -413,7 +414,7 @@ class VouchersByPartnerBase(dd.VirtualTable):
 
     order_by = ["-entry_date", '-id']
     master = 'contacts.Partner'
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
     _master_field_name = 'partner'
     # _voucher_base = PartnerRelated
