@@ -920,7 +920,7 @@ class RegistrableVoucher(Registrable, Voucher):
                 m.save()
                 if m.partner:
                     partners.add(m.partner)
-            if settings.SITE.history_aware_logging:
+            if settings.SITE._history_aware_logging:
                 dd.logger.info("Register %s (%d movements, %d partners)",
                     self, seqno, len(partners))
 
@@ -929,7 +929,7 @@ class RegistrableVoucher(Registrable, Voucher):
     def deregister_voucher(self, ar, do_clear=True):
 
         def doit(partners):
-            if settings.SITE.history_aware_logging:
+            if settings.SITE._history_aware_logging:
                 dd.logger.info("Deregister %s (%d partners)", self, len(partners))
 
         self.do_and_clear(doit, do_clear)
