@@ -16,7 +16,7 @@ from .mixins import JournalRef, PeriodRangeObservable
 from .roles import AccountingReader, LedgerUser, LedgerStaff, LedgerPartner
 from .utils import Balance
 from .utils import DC, ZERO
-
+from lino.core import constants
 
 has_payment_methods = dd.get_plugin_setting('ledger', 'has_payment_methods', False)
 
@@ -66,7 +66,7 @@ class Journals(dd.Table):
 class JournalsOverview(Journals):
     required_roles = dd.login_required(LedgerUser)
     column_names = "description num_vouchers this_year this_month state_draft warnings *"
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     editable = False
 
 
@@ -488,6 +488,7 @@ def mvtsum(**fkw):
         **fkw).aggregate(models.Sum('amount'))
     return d['amount__sum'] or ZERO
 
+
 class AccountingPeriodRange(dd.ParameterPanel):
     def __init__(self,
                  verbose_name_start=_("Period from"),
@@ -525,12 +526,13 @@ class AccountingPeriodRange(dd.ParameterPanel):
         else:
             yield str(_("All periods"))
 
+
 class AccountBalances(dd.Table):
     editable = False
     required_roles = dd.login_required(AccountingReader)
     auto_fit_column_widths = True
     column_names = "description old_d old_c empty_column:1 during_d during_c empty_column:1 new_d new_c"
-    display_mode_main = 'html'
+    display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     abstract = True
     params_panel_hidden = False
     use_as_default_table = False
@@ -716,7 +718,7 @@ class DebtorsCreditors(dd.VirtualTable):
     required_roles = dd.login_required(AccountingReader)
     auto_fit_column_widths = True
     column_names = "age due_date partner partner_id balance vouchers"
-    display_mode_main = 'html'
+    display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     abstract = True
 
     parameters = mixins.Today()
@@ -1030,7 +1032,7 @@ class MovementsByVoucher(Movements):
     column_names = 'account project partner debit credit match_link cleared *'
     sum_text_column = 3
     # auto_fit_column_widths = True
-    display_mode_main = "html"
+    display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     order_by = dd.plugins.ledger.remove_dummy(
         'seqno', 'value_date', 'account__ref', 'partner', 'project', 'id')
 
@@ -1039,8 +1041,7 @@ class MovementsByPartner(Movements):
     editable = True
     allow_create = False
     master_key = 'partner'
-    # display_mode_main = "html"
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     # auto_fit_column_widths = True
     # order_by = ['-value_date', 'voucher__id', 'account__ref']
     order_by = dd.plugins.ledger.remove_dummy(
@@ -1119,7 +1120,7 @@ class MovementsByProject(MovementsByPartner):
     column_names = 'value_date voucher_link description \
     debit credit match_link cleared *'
     master_key = 'project'
-    display_mode_main = "html"
+    display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     order_by = ['-value_date', 'partner', 'id']
 
 
@@ -1149,7 +1150,7 @@ class MovementsByAccount(Movements):
     debit credit match_link *'
     # order_by = ['-value_date']
     # auto_fit_column_widths = True
-    display_mode_main = "html"
+    display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     # order_by = ['-value_date', 'account__ref', 'project', 'id']
     order_by = dd.plugins.ledger.remove_dummy(
         '-value_date', 'partner__name', 'project', 'id')
