@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2017-2021 Rumma & Ko Ltd
+# Copyright 2017-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
@@ -15,7 +15,7 @@ from lino.core.roles import SiteStaff
 
 from .choicelists import ContactDetailTypes
 from .mixins import ContactDetailsOwner
-
+from lino.core import constants
 
 
 class ContactDetail(DateRange):
@@ -121,7 +121,7 @@ class ContactDetailsByPartner(ContactDetails):
     stay_in_grid = True
     window_size = (80, 20)
 
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
     @classmethod
     def get_table_summary(self, obj, ar):
