@@ -19,6 +19,7 @@ from lino.modlib.memo.mixins import truncate_comment
 
 from .utils import ResponseStates, PollStates
 from .roles import PollsUser, PollsStaff
+from lino.core import constants
 
 NullBooleanField = models.NullBooleanField
 
@@ -381,7 +382,7 @@ class ResponsesByPoll(Responses):
 class ResponsesByPartner(Responses):
     master_key = 'partner'
     column_names = 'date user state remark *'
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
     @classmethod
     def get_table_summary(self, obj, ar):
@@ -599,7 +600,7 @@ class AnswersByResponseEditor(AnswersByResponseBase):
     column_names = 'question:40 answer_buttons:30 remark:20 *'
     variable_row_height = True
     auto_fit_column_widths = True
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     # workflow_state_field = 'state'
 
     remark = AnswerRemarkField()
@@ -724,7 +725,7 @@ class AnswersByResponseEditor(AnswersByResponseBase):
 
 
 class AnswersByResponsePrint(AnswersByResponseBase):
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     column_names = 'question *'
 
     @classmethod
