@@ -1,6 +1,5 @@
 # coding: UTF-8
-# Copyright 2011-2016 Rumma & Ko Ltd
-#
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """Database models for `lino_xl.lib.thirds`.
 
@@ -17,7 +16,7 @@ from lino.api import dd
 from lino import mixins
 from lino_xl.lib.contacts import models as contacts
 from lino.modlib.gfks.mixins import Controllable
-
+from lino.core import constants
 
 
 class Third(mixins.Sequenced, contacts.PartnerDocument, Controllable):
@@ -46,4 +45,4 @@ class Thirds(dd.Table):
 class ThirdsByController(Thirds):
     master_key = 'owner'
     column_names = "seqno person company id *"
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
