@@ -30,7 +30,7 @@ from lino_xl.lib.votes.choicelists import VoteStates
 from lino_xl.lib.votes.mixins import Votable
 from lino_xl.lib.working.choicelists import ReportingTypes
 from lino_xl.lib.working.mixins import Workable
-from .choicelists import TicketStates, LinkTypes, Priorities, SiteStates
+from .choicelists import TicketStates, Priorities, SiteStates
 
 MessageTypes.add_item('tickets', dd.plugins.tickets.verbose_name)
 
@@ -430,33 +430,17 @@ class SpawnTicket(dd.Action):
             blank=False)
         )
 
-    # def setup_parameters(self, params):
-    #     super(SpawnTicket, self).setup_parameters(params)
-    #     params.update(
-    #         link_type=db2param('tickets.Link.type'),
-    #         ticket_summary=db2param('tickets.Ticket.summary'))
-
     def run_from_ui(self, ar, **kw):
         pv = ar.action_param_values
         parent = ar.selected_rows[0]
+        user = ar.get_user()
         child = rt.models.tickets.Ticket(
-            user=ar.get_user(),
+            user=user,
             summary=pv.ticket_summary,
             site=parent.site,
             parent=parent)
         child.full_clean()
         child.save_new_instance(ar)
-        # parent.comments.create(body="@" + ar.get_user().username + " " + _("created new child ticket") + " " + "#" + str(child.id))
-        comment = rt.models.comments.Comment(
-            body="@" + ar.get_user().username + " " + _("created new child ticket") + " " + "#" + str(child.id)
-        )
-        comment.owner = parent
-        comment.full_clean()
-        comment.save_new_instance(ar)
-        # link = rt.models.tickets.Link(
-        #     parent=parent, child=child, type=pv.link_type)
-        # link.full_clean()
-        # link.save(force_insert=True)
         ar.goto_instance(child)
         ar.success()
 
@@ -531,10 +515,6 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
         _("Feedback"), default=False)
     standby = models.BooleanField(_("Standby"), default=False)
 
-    # spawn_triggered = SpawnTicket(
-    #     _("Spawn triggered ticket"),
-    #     LinkTypes.triggers)
-    # spawn_triggered = SpawnTicket("⚇", LinkTypes.triggers)  # "\u2687"
     spawn_ticket = SpawnTicket()  # "\u2687"
 
     fixed_since = models.DateTimeField(
@@ -595,6 +575,20 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
                 Q(private=False, site__private=False)).distinct()
         return qs
 
+    # write_comment_on_create = True
+
+    # def get_create_comment(self, ar):
+    #     # causes Commentable.save_new_instance() to create a comment
+    #     p = dd.plugins.memo.parser
+    #     txt = _("{user} created new {model} {row}").format(
+    #             model=self.__class__._meta.verbose_name,
+    #             user=p.obj2memo(ar.get_user()),
+    #             row=p.obj2memo(self))
+    #     if self.parent is not None:
+    #         txt += " " + _("from {row}").format(row=str(self.parent))
+    #     txt += "."
+    #     return txt
+
     def is_comment_private(self, comment, ar):
         if self.site_id and self.site.private:
             return True
@@ -827,72 +821,6 @@ class CheckListItem(dd.Model):
     checked = dd.BooleanField(_("Finished"), default=False)
 
 
-
-class Link(dd.Model):
-    class Meta:
-        app_label = 'tickets'
-        verbose_name = _("Dependency")
-        verbose_name_plural = _("Dependencies")
-
-    allow_cascaded_delete = 'parent child'
-    # when i delete a ticket that is child of another ticket, then Lino also
-    # deletes the relationship with the ticket. But Lino does not allow me to
-    # delete a ticket that is itself parent to one or more other tickets.
-
-    type = LinkTypes.field(default='requires')
-    parent = dd.ForeignKey(
-        'tickets.Ticket',
-        verbose_name=_("Parent"),
-        related_name='tickets_children')
-    child = dd.ForeignKey(
-        'tickets.Ticket',
-        blank=True, null=True,
-        verbose_name=_("Child"),
-        related_name='tickets_parents')
-
-    @dd.displayfield(_("Type"))
-    def type_as_parent(self, ar):
-        # print('20140204 type_as_parent', self.type)
-        return self.type.as_parent()
-
-    @dd.displayfield(_("Type"))
-    def type_as_child(self, ar):
-        # print('20140204 type_as_child', self.type)
-        return self.type.as_child()
-
-    def __str__(self):
-        if self.type is None:
-            return "Link object"  # super(Link, self).__unicode__()
-        return _("%(child)s is %(what)s") % dict(
-            child=str(self.child),
-            what=self.type_of_parent_text())
-
-    def type_of_parent_text(self):
-        return _("%(type)s of %(parent)s") % dict(
-            parent=self.parent,
-            type=self.type.as_child())
-
-
-class LinkChecker(Checker):
-
-    verbose_name = _("Find dependencies that will get lost")
-    model = 'tickets.Link'
-
-    def get_checkdata_problems(self, obj, fix=False):
-        if obj.child is None or obj.parent is None:
-            return
-        if obj.child.parent != obj.parent:
-            yield (True, _("{} but parent is {}").format(obj, obj.child.parent))
-            if fix:
-                obj.child.parent = obj.parent
-                obj.child.full_clean()
-                obj.child.save()
-
-
-LinkChecker.activate()
-
-
-
 # dd.inject_field(
 #     'users.User', 'project',
 #     dd.ForeignKey(
