@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.conf import settings
@@ -17,6 +17,7 @@ from lino_xl.lib.cal.mixins import daterange_text
 from .choicelists import TicketEvents, TicketStates, Priorities, SiteStates
 # from .choicelists import LinkTypes
 from .roles import TicketsReader, Reporter, Searcher, Triager, TicketsStaff
+from lino.core import constants
 
 site_model = dd.plugins.tickets.site_model
 milestone_model = dd.plugins.tickets.milestone_model
@@ -163,7 +164,7 @@ class TicketTypes(dd.Table):
 #     required_roles = dd.login_required(Triager)
 #     master = 'tickets.Ticket'
 #     column_names = 'parent type_as_parent:10 child'
-#     display_mode_main = 'summary'
+#     display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 #
 #     @classmethod
 #     def get_request_queryset(self, ar):
@@ -533,7 +534,7 @@ class AllTickets(Tickets):
 
 
 class DuplicatesByTicket(Tickets):
-    display_mode_main = 'html'
+    display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     label = _("Duplicates")
     master_key = 'duplicate_of'
     column_names = "overview state *"
@@ -581,7 +582,7 @@ class UnassignedTickets(Tickets):
 class TicketsByEndUser(Tickets):
     master_key = 'end_user'
     column_names = ("overview:50 workflow_buttons * ")
-    # display_mode_main = "summary"
+    # display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     required_roles = dd.login_required(TicketsReader)
 
     @classmethod
@@ -741,7 +742,7 @@ class MyTickets(My, Tickets):
 # class TicketsSummary(Tickets):
 #     # order_by = ["state", "priority", "-id"]
 #     order_by = ["priority", "-id"]
-#     display_mode_main = 'summary'
+#     display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 #
 #     @classmethod
 #     def get_table_summary(self, master, ar):
