@@ -1,25 +1,11 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2021 Rumma & Ko
+# Copyright 2013-2022 Rumma & Ko
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-
-
-"""See :doc:`/plugins/vat`.
-
-.. autosummary::
-   :toctree:
-
-    utils
-
-
-"""
+# Developer docs: https://dev.lino-framework.org/plugins/vat.html
 
 from lino.api import ad, _
 
 class Plugin(ad.Plugin):
-    """The :class:`Plugin <lino.core.plugin.Plugin>` object for this
-    plugin.
-
-    """
     verbose_name = _("VAT")
     # menu_group = "vat"
 
@@ -29,46 +15,11 @@ class Plugin(ad.Plugin):
     "FI", "FR", "GR", "HU", "HR", "IE", "IT", "LV", "LT", "LU", "MT", "NL",
     "PO", "PT", "RO", "SE", "SI", "SK"}
 
-    """A set of ISO codes that are to be considered part of the EU. See
-    :ref:`dg.plugins.vat.eu_country_codes`.
-
-    """
-
     default_vat_regime = 'normal'
-    """The default VAT regime. If this is specified as a string, Lino will
-    resolve it at startup into an item of :class:`VatRegimes
-    <lino_xl.lib.vat.VatRegimes>`.
-
-    """
-
     default_vat_class = 'services'
-    """The default VAT class. If this is specified as a string, Lino will
-    resolve it at startup into an item of :class:`VatClasses
-    <lino_xl.lib.vat.VatClasses>`.
-
-    """
-
     declaration_plugin = None
-    """The plugin to use as your :term:`national VAT module`.
-
-    Available modules are:
-    :mod:`lino_xl.lib.bevat`,
-    :mod:`lino_xl.lib.bevats` and
-    :mod:`lino_xl.lib.eevat`.
-
-    This may remain `None`, e.g. in applicatons that use the ledger plugin for
-    orders or invoicing without caring about general accounting functionality.
-
-    """
-
     item_vat = False
-    """Whether item prices in trade documents are meant VAT included.
-    """
-
     use_online_check = False
-    """Whether to verify :term:`VAT numbers <VAT number>` online via `VIES
-    <https://ec.europa.eu/taxation_customs/vies/>`__.
-    """
 
     def get_vat_class(self, tt, item):
         """Return the VAT class to be used for given trade type and given
