@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2015-2020 Rumma & Ko Ltd
+# Copyright 2015-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from decimal import Decimal
@@ -8,13 +8,13 @@ from django.db import models
 
 from lino.utils import SumCollector
 from lino_xl.lib.ledger.mixins import (
-    Payable, ProjectRelated, AccountVoucherItem, Matching)
+    Payable, PartnerRelated, ProjectRelated, AccountVoucherItem, Matching)
 from lino_xl.lib.sepa.mixins import BankAccount
 from lino_xl.lib.ledger.models import RegistrableVoucher, VoucherStates
 from lino.api import dd, _
 
 
-class AccountInvoice(BankAccount, Payable, RegistrableVoucher, Matching, ProjectRelated):
+class AccountInvoice(BankAccount, PartnerRelated, Payable, RegistrableVoucher, Matching, ProjectRelated):
 
     class Meta:
         app_label = 'vatless'
