@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import sys
@@ -28,7 +28,7 @@ from lino_xl.lib.calview.ui import Day, ParameterClone, DayNavigator, DaySlave,
 
 from .roles import Worker
 from .choicelists import ReportingTypes
-
+from lino.core import constants
 
 class TOTAL_KEY(object):
     pass
@@ -162,7 +162,7 @@ class SessionsByTicket(Sessions):
     master_key = 'ticket'
     column_names = 'start_date summary start_time end_time  '\
                    'break_time duration user is_fixing *'
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 
     @classmethod
     def get_table_summary(self, obj, ar):
@@ -760,7 +760,7 @@ class MySessionsByDay(MySessionsByDate):
 #class MySessionsByDay(MySessionsByDate, DaySlave):
     # with_header_row = False
     master = 'working.Day'
-    # display_mode_main = "html"
+    # display_mode = ((None, constants.DISPLAY_MODE_HTML),)
     # use_detail_params_value = True
 
     @classmethod
